# snowcross-python

Adaptors for tools and services in a Snowflake-centric data platform.

> **WARNING** While this repository is private, releases are published _publicly_ to 
> [PyPI](https://pypi.org/project/snowcross/)! All commits, pull requests and this readme are
> hidden, however the source code is easily extracted from published artifacts. Refrain from
> including any references to proprietary code, infrastructure or architecture. This package is
> for generic utilities for tools and services only.

## Requirements

Requires Python 3.10 or above.

## Usage

You can install from [PyPI](https://pypi.org/project/snowcross/):

```shell
pip install snowcross
```

When using `locator` functionality, install extra dependencies `snowcross[locator]`.
